==> autoprefixer-1.0.20140110.tgz: package/data/browsers.js <==
(function() {
  module.exports = {
    android: {
      prefix: "-webkit-",
      minor: true,
      future: [4.4],
      versions: [4.3, 4.2, 4.1, 4, 3, 2.3, 2.2, 2.1],
      popularity: [0.53036, 0.53036, 2.31995, 1.15377, 0.00620307, 1.49494, 0.0992491, 0.0310153]
    },
    bb: {
      prefix: "-webkit-",
      minor: true,
      versions: [10, 7],
      popularity: [0, 0.177331]
    },
    chrome: {
      prefix: "-webkit-",
      future: [33, 32],
      versions: [31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4],
      popularity: [30.1841, 0.628038, 0.528471, 0.329337, 0.359973, 0.30636, 0.15318, 0.091908, 0.107226, 0.130203, 0.444222, 0.045954, 0.038295, 0.107226, 0.030636, 0.045954, 0.068931, 0.053613, 0.053613, 0.068931, 0.122544, 0.038295, 0.022977, 0.030636, 0.022977, 0.030636, 0.022977, 0.030636]
    },
    ff: {
      prefix: "-moz-",
      future: [28, 27],
      versions: [26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3.6, 3.5, 3, 2],
      popularity: [4.77922, 7.50582, 0.359973, 0.199134, 0.168498, 0.183816, 0.137862, 0.107226, 0.091908, 0.160839, 0.176157, 0.107226, 0.084249, 0.084249, 0.191475, 0.084249, 0.107226, 0.053613, 0.068931, 0.038295, 0.045954, 0.038295, 0.061272, 0.260406, 0.038295, 0.091908, 0.015318]
    },
    ie: {
      prefix: "-ms-",
      versions: [11, 10, 9, 8, 7, 6, 5.5],
      popularity: [5.39701, 4.67264, 3.38308, 5.8189, 0.254726, 0.302487, 0.009298]
    },
    ios: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4.3, 4.2, 4.1, 4, 3.2],
      popularity: [3.50034, 0.541895, 0.541895, 0.144017, 0.144017, 0.0146458, 0.0146458, 0.004881925, 0.004881925, 0.00488193]
    },
    opera: {
      prefix: "-o-",
      future: [20, 19],
      versions: [18, 17, 16, 15, 12.1, 12, 11.6, 11.5, 11.1, 11, 10.6, 10.5, 10.1, 10, 9.6, 9.5],
      popularity: [0.321678, 0.038295, 0.022977, 0.022977, 0.451881, 0.038295, 0.030636, 0.015318, 0.008219, 0.008219, 0.015318, 0.008392, 0.007659, 0.007659, 0.0038295, 0.0038295]
    },
    safari: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4, 3.2, 3.1],
      popularity: [0.873126, 0.773559, 0.68931, 0.934398, 0.275724, 0.114885, 0.008692, 0]
    }
  };

}).call(this);

==> autoprefixer-1.0.20140117.tgz: package/data/browsers.js <==
(function() {
  module.exports = {
    android: {
      prefix: "-webkit-",
      minor: true,
      future: [4.4],
      versions: [4.3, 4.2, 4.1, 4, 3, 2.3, 2.2, 2.1],
      popularity: [0.53036, 0.53036, 2.31995, 1.15377, 0.00620307, 1.49494, 0.0992491, 0.0310153]
    },
    bb: {
      prefix: "-webkit-",
      minor: true,
      versions: [10, 7],
      popularity: [0, 0.177331]
    },
    chrome: {
      prefix: "-webkit-",
      future: [34, 33],
      versions: [32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4],
      popularity: [0.513153, 30.1841, 0.628038, 0.528471, 0.329337, 0.359973, 0.30636, 0.15318, 0.091908, 0.107226, 0.130203, 0.444222, 0.045954, 0.038295, 0.107226, 0.030636, 0.045954, 0.068931, 0.053613, 0.053613, 0.068931, 0.122544, 0.038295, 0.022977, 0.030636, 0.022977, 0.030636, 0.022977, 0.030636]
    },
    ff: {
      prefix: "-moz-",
      future: [28, 27],
      versions: [26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3.6, 3.5, 3, 2],
      popularity: [4.77922, 7.50582, 0.359973, 0.199134, 0.168498, 0.183816, 0.137862, 0.107226, 0.091908, 0.160839, 0.176157, 0.107226, 0.084249, 0.084249, 0.191475, 0.084249, 0.107226, 0.053613, 0.068931, 0.038295, 0.045954, 0.038295, 0.061272, 0.260406, 0.038295, 0.091908, 0.015318]
    },
    ie: {
      prefix: "-ms-",
      versions: [11, 10, 9, 8, 7, 6, 5.5],
      popularity: [5.39701, 4.67264, 3.38308, 5.8189, 0.254726, 0.302487, 0.009298]
    },
    ios: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4.3, 4.2, 4.1, 4, 3.2],
      popularity: [3.50034, 0.541895, 0.541895, 0.144017, 0.144017, 0.0146458, 0.0146458, 0.004881925, 0.004881925, 0.00488193]
    },
    opera: {
      prefix: "-o-",
      future: [20, 19],
      versions: [18, 17, 16, 15, 12.1, 12, 11.6, 11.5, 11.1, 11, 10.6, 10.5, 10.1, 10, 9.6, 9.5],
      popularity: [0.321678, 0.038295, 0.022977, 0.022977, 0.451881, 0.038295, 0.030636, 0.015318, 0.008219, 0.008219, 0.015318, 0.008392, 0.007659, 0.007659, 0.0038295, 0.0038295]
    },
    safari: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4, 3.2, 3.1],
      popularity: [0.873126, 0.773559, 0.68931, 0.934398, 0.275724, 0.114885, 0.008692, 0]
    }
  };

}).call(this);
